==> cmsmadesimple-1.5.3.tgz: cms/modules/FileManager/lang/ext/fr_FR.php <==
<?php
$lang['friendlyname'] = 'Gestionnaire de Fichiers';
$lang['permission'] = 'Utilisation du Gestionnaire de Fichiers';
$lang['permissionadvanced'] = 'Utilisation avanc&eacute;e du Gestionnaire de Fichiers';
$lang['moddescription'] = 'Gestion des fichiers et dossiers dans la section &quot;uploads&quot; de CMSMS';
$lang['installed'] = 'La version %s du Gestionnaire de Fichiers a &eacute;t&eacute; install&eacute;e';
$lang['postinstall'] = 'Le module Gestionnaire de Fichiers a &eacute;t&eacute; install&eacute;';
$lang['uninstalled'] = 'Le module  Gestionnaire de Fichiers a &eacute;t&eacute; d&eacute;sinstall&eacute;';
$lang['really_uninstall'] = '\312tes-vous s\373r de vouloir d\351sinstaller le module Gestionnaire de Fichiers ?';
$lang['upgraded'] = 'Le module Gestionnaire de Fichiers a &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
$lang['fileview'] = 'Vue fichier';
$lang['switchtofileview'] = 'Passer en visualisateur de fichier';
$lang['settings'] = 'Param&egrave;tres';
$lang['savesettings'] = 'Envoyer';
$lang['filename'] = 'Nom de fichier';
$lang['fileinfo'] = 'Information&nbsp;';
$lang['fileowner'] = 'Prop. fichier&nbsp;';
$lang['fileperms'] = 'Perm&nbsp;';
$lang['filesize'] = 'Taille';
$lang['filedate'] = 'Date ';
$lang['actions'] = 'Actions ';
$lang['delete'] = 'Supprimer';
$lang['notwritable'] = '&Eacute;criture impossible';
$lang['filetoobig'] = 'Taille trop grosse. T&eacute;l&eacute;chargement annul&eacute;.';
$lang['unknown'] = 'Inconnu';
$lang['fileoutsideuploads'] = 'Vous n&#039;&ecirc;tes pas autoris&eacute; &agrave; modifier des fichiers en dehors du dossier upload ! (Exige l&#039;autorisation d&#039;activer le mode avanc&eacute;)';
$lang['writable'] = '&Eacute;criture';
$lang['writeprotected'] = 'Prot&eacute;g&eacute; en &eacute;criture';
$lang['bytes'] = 'octets';
$lang['kb'] = 'Ko';
$lang['mb'] = 'Mo';
$lang['files'] = 'Fichiers';
$lang['bytesin'] = 'octets dans';
$lang['in'] = 'dans';
$lang['file'] = 'Fichier';
$lang['fileno'] = 'Fichier n&deg;&nbsp;';
$lang['subdirs'] = 'sous-dossiers';
$lang['subdir'] = 'sous-dossier';
$lang['and'] = 'et';
$lang['confirmsingledelete'] = '&Ecirc;tes-vous s&ucirc;r ?';
$lang['confirmsingledirdelete'] = '&Ecirc;tes-vous s&ucirc;r de supprimer ce dossier ?';
$lang['dirtreedeletesuccess'] = 'Le dossier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['dirtreedeletefail'] = 'Une erreur est survenue lors de la suppression du dossier. Une partie des fichiers sont effac&eacute;s, cependant.';
$lang['singlefiledeletesuccess'] = 'Le fichier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['filedeletesuccess'] = ' a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['singlefiledeletefail'] = 'Une erreur est survenue lors de la suppression du fichier';
$lang['filedeletefail'] = ' n&#039;a pas &eacute;t&eacute; supprim&eacute;, une erreur est survenue';
$lang['singledirdeletesuccess'] = 'Le dossier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['singledirdeletefail'] = 'Une erreur est survenue lors de la suppression du dossier (est-il vide?)';
$lang['deleteselected'] = 'Supprimer les fichiers s&eacute;lectionn&eacute;s';
$lang['confirmselected'] = '&Ecirc;tes-vous s&ucirc;r ?';
$lang['confirmdeleteselected'] = '&Ecirc;tes-vous s&ucirc;r que les fichiers s&eacute;lectionn&eacute;s peuvent &ecirc;tre supprim&eacute;s ? ';
$lang['deleteselectedcancelled'] = 'Annulation de la s&eacute;lection des fichiers';
$lang['recursetext'] = 'R&eacute;cursion dans les sous-dossier';
$lang['nofilesselected'] = 'Aucun fichier s&eacute;lectionn&eacute;';
$lang['moveselected'] = 'D&eacute;placer les fichiers s&eacute;lectionn&eacute;s';
$lang['copyselected'] = 'Copier les fichiers s&eacute;lectionn&eacute;s';
$lang['selecttargetdir'] = 'S&eacute;lectionner le dossier de destination pour D&eacute;placer/Copier';
$lang['movedto'] = 'D&eacute;plac&eacute; vers';
$lang['copiedto'] = 'Copier vers';
$lang['couldnotmove'] = 'Ne peut pas &ecirc;tre d&eacute;plac&eacute;';
$lang['couldnotcopy'] = 'Ne peut pas &ecirc;tre copi&eacute;';
$lang['rename'] = 'Renommer';
$lang['newname'] = 'Nouveau nom&nbsp;:';
$lang['renamesuccess'] = 'Le fichier a &eacute;t&eacute; renomm&eacute; avec succ&egrave;s';
$lang['renamefailure'] = 'Le fichier n&#039;a pas &eacute;t&eacute; renomm&eacute;';
$lang['renamecancelled'] = 'Le changement de nom a &eacute;t&eacute; annul&eacute;';
$lang['owner'] = 'Propri&eacute;taire';
$lang['group'] = 'Groupe';
$lang['others'] = 'Autres';
$lang['newpermissions'] = 'Nouvelles permissions&nbsp;:';
$lang['setpermissions'] = 'Donner les permissions';
$lang['permissionstyle'] = 'Style de permissions';
$lang['rwxstyle'] = 'Style rwx';
$lang['755style'] = 'Style 755';
$lang['quickmode'] = 'Chmod rapide (ex : 777)&nbsp;';
$lang['chmod'] = 'Changer les permissions';
$lang['chmodselected'] = 'Changer les permissions sur les fichiers s&eacute;lectionn&eacute;s';
$lang['chmodsuccess'] = 'Le fichier a les nouvelles permissions';
$lang['chmodfailure'] = 'Le fichier n&#039;a pas les nouvelles permissions';
$lang['chmodcancelled'] = 'Le changement des permissions a &eacute;t&eacute; annul&eacute;';
$lang['dirchmodfailmulti'] = 'La modification des permissions sur le dossier a &eacute;chou&eacute;e, une partie du contenu a obtenu de permissions.';
$lang['dirchmodsuccessmulti'] = 'Le changement des permissions sur le dossier et son contenu a &eacute;t&eacute; fait avec succ&egrave;s';
$lang['dirchmodsuccess'] = 'Les permissions sur le dossier sont modifi&eacute;es';
$lang['dirchmodfailure'] = 'La modification des permissions sur le dossier a &eacute;chou&eacute;e';
$lang['dirnotemptyconfirm'] = 'Ce dossier n&#039;est pas vide. Voulez-vous le supprimer ainsi que tout le contenu, y compris les sous dossier ?';
$lang['dirtreedeletecancelled'] = 'Annulation de suppression de dossier';
$lang['imsure'] = 'Je suis s&ucirc;r(e)';
$lang['cancel'] = 'Annuler';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'T&eacute;l&eacute;charger un nouveau fichier&nbsp;:';
$lang['unpackafterupload'] = 'Tentative de d&eacute;compression apr&egrave;s le t&eacute;l&eacute;chargement ?';
$lang['uploadsuccess'] = 'Votre fichier a &eacute;t&eacute; correctement t&eacute;l&eacute;charg&eacute;';
$lang['uploadfail'] = 'Une erreur est survenue lors du t&eacute;l&eacute;chargement du fichier';
$lang['unpacksuccess'] = 'Votre fichier a &eacute;t&eacute; correctement d&eacute;compress&eacute;';
$lang['unpackfail'] = 'Une erreur est survenue lors de la d&eacute;compression du fichier&nbsp;:';
$lang['packfileopenfail'] = 'L&#039;ouverture du fichier archive n&#039;a pas pu s&#039;effectuer par d&eacute;compression (format non-support&eacute;)';
$lang['packfilewritefail'] = 'L&#039;ouverture du fichier &amp;s pour &eacute;criture n&#039;a pas pu s&#039;effectuer';
$lang['currentpath'] = 'Chemin actuel&nbsp;:';
$lang['newdirname'] = 'Cr&eacute;er un nouveau dossier&nbsp;:';
$lang['newdirsuccess'] = 'Le dossier a &eacute;t&eacute; cr&eacute;&eacute; avec succ&egrave;s';
$lang['newdirfail'] = 'Une erreur est survenue lors de la cr&eacute;ation du dossier';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Taille ic&ocirc;ne';
$lang['smallicons'] = 'Petite ic&ocirc;ne';
$lang['largeicons'] = 'Grande ic&ocirc;ne';
$lang['thousanddelimiter'] = 'S&eacute;parateur des miliers';
$lang['none'] = 'Aucun';
$lang['showthumbnails'] = 'Afficher les vignettes';
$lang['showthumbnailshelp'] = 'Si coch&eacute; montre les vignettes des fichiers images si elles existent, et cache les &icirc;cones des fichiers. Non coch&eacute; affiche tous les fichiers.';
$lang['uploadfilesto'] = 'T&eacute;l&eacute;charger les fichiers vers&nbsp;:';
$lang['uploadview'] = 'T&eacute;l&eacute;charger les fichiers';
$lang['uploadboxes'] = 'Nombre de fichiers &agrave; t&eacute;l&eacute;charger ';
$lang['nothinguploaded'] = 'Rien n&#039;a &eacute;t&eacute; t&eacute;l&eacute;charg&eacute;';
$lang['unsupportedarchive'] = 'Format  non support&eacute;';
$lang['uploadmethod'] = 'M&eacute;thode de t&eacute;l&eacute;chargement';
$lang['uploaderstandard'] = 'M&eacute;thode standard html (d&eacute;compression autoris&eacute;e)';
$lang['enableadvanced'] = 'Activer le mode avanc&eacute; ? (si autoris&eacute;)';
$lang['advancedhelp'] = 'Donner acc&egrave;s &agrave; TOUT le syst&egrave;me de fichiers de l&#039;installation CMSMS, pas uniquement &agrave; /uploads/ (si autoris&eacute;)';
$lang['showhiddenfileshelp'] = 'Ne fonctionne qu&#039;en mode avanc&eacute;';
$lang['showhiddenfiles'] = 'Afficher les fichiers cach&eacute;s';
$lang['settingsconfirmsingledelete'] = 'Confirmer la suppression d&#039;un fichier seul ?';
$lang['settingssaved'] = 'Param&egrave;tres sauvegard&eacute;s';
$lang['help'] = '		<h3>Que fait ce module ?</h3>
		<p>Le module Gestionnaire de Fichiers (File Manager) offre des fonctions de gestion de fichiers, et esp&egrave;re remplacer avantageusement le Gestionnaire de Fichiers actuel</p>
		<h3>Comment l&#039;utiliser ?</h3>
		<p>S&eacute;lectionnez-le depuis le menu Contenu de l&#039;administration. Si l&#039;ancien gestionnaire de fichier est pr&eacute;sent, vous devriez trouver celui-ci un peu plus bas dans le menu.</p>';
$lang['utma'] = '156861353.1056341972.1234106418.1234106418.1234106418.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1234106418.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>

==> cmsmadesimple-1.6.6.tgz: cms/modules/FileManager/lang/ext/fr_FR.php <==
<?php
$lang['friendlyname'] = 'Gestionnaire de Fichiers';
$lang['permission'] = 'Utilisation du Gestionnaire de Fichiers';
$lang['permissionadvanced'] = 'Utilisation avanc&eacute;e du Gestionnaire de Fichiers';
$lang['moddescription'] = 'Gestion des fichiers et dossiers dans la section &quot;uploads&quot; de CMSMS';
$lang['installed'] = 'La version %s du Gestionnaire de Fichiers a &eacute;t&eacute; install&eacute;e';
$lang['postinstall'] = 'Le module Gestionnaire de Fichiers a &eacute;t&eacute; install&eacute;';
$lang['uninstalled'] = 'Le module  Gestionnaire de Fichiers a &eacute;t&eacute; d&eacute;sinstall&eacute;';
$lang['really_uninstall'] = '\312tes-vous s\373r de vouloir d\351sinstaller le module Gestionnaire de Fichiers ?';
$lang['upgraded'] = 'Le module Gestionnaire de Fichiers a &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
$lang['fileview'] = 'Vue fichier';
$lang['switchtofileview'] = 'Passer en visualisateur de fichier';
$lang['settings'] = 'Param&egrave;tres';
$lang['savesettings'] = 'Envoyer';
$lang['filename'] = 'Nom de fichier';
$lang['fileinfo'] = 'Information&nbsp;';
$lang['fileowner'] = 'Prop. fichier&nbsp;';
$lang['fileperms'] = 'Perm&nbsp;';
$lang['filesize'] = 'Taille';
$lang['filedate'] = 'Date ';
$lang['actions'] = 'Actions ';
$lang['delete'] = 'Supprimer';
$lang['notwritable'] = '&Eacute;criture impossible';
$lang['filetoobig'] = 'Taille trop grosse. T&eacute;l&eacute;chargement annul&eacute;.';
$lang['unknown'] = 'Inconnu';
$lang['fileoutsideuploads'] = 'Vous n&#039;&ecirc;tes pas autoris&eacute; &agrave; modifier des fichiers en dehors du dossier upload ! (Exige l&#039;autorisation d&#039;activer le mode avanc&eacute;)';
$lang['writable'] = '&Eacute;criture';
$lang['writeprotected'] = 'Prot&eacute;g&eacute; en &eacute;criture';
$lang['bytes'] = 'octets';
$lang['kb'] = 'Ko';
$lang['mb'] = 'Mo';
$lang['files'] = 'Fichiers';
$lang['bytesin'] = 'octets dans';
$lang['in'] = 'dans';
$lang['file'] = 'Fichier';
$lang['fileno'] = 'Fichier n&deg;&nbsp;';
$lang['subdirs'] = 'sous-dossiers';
$lang['subdir'] = 'sous-dossier';
$lang['and'] = 'et';
$lang['confirmsingledelete'] = '&Ecirc;tes-vous s&ucirc;r ?';
$lang['confirmsingledirdelete'] = '&Ecirc;tes-vous s&ucirc;r de supprimer ce dossier ?';
$lang['dirtreedeletesuccess'] = 'Le dossier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['dirtreedeletefail'] = 'Une erreur est survenue lors de la suppression du dossier. Une partie des fichiers sont effac&eacute;s, cependant.';
$lang['singlefiledeletesuccess'] = 'Le fichier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['filedeletesuccess'] = ' a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['singlefiledeletefail'] = 'Une erreur est survenue lors de la suppression du fichier';
$lang['filedeletefail'] = ' n&#039;a pas &eacute;t&eacute; supprim&eacute;, une erreur est survenue';
$lang['singledirdeletesuccess'] = 'Le dossier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
$lang['singledirdeletefail'] = 'Une erreur est survenue lors de la suppression du dossier (est-il vide?)';
$lang['deleteselected'] = 'Supprimer les fichiers s&eacute;lectionn&eacute;s';
$lang['confirmselected'] = '&Ecirc;tes-vous s&ucirc;r ?';
$lang['confirmdeleteselected'] = '&Ecirc;tes-vous s&ucirc;r que les fichiers s&eacute;lectionn&eacute;s peuvent &ecirc;tre supprim&eacute;s ? ';
$lang['deleteselectedcancelled'] = 'Annulation de la s&eacute;lection des fichiers';
$lang['recursetext'] = 'R&eacute;cursion dans les sous-dossier';
$lang['nofilesselected'] = 'Aucun fichier s&eacute;lectionn&eacute;';
$lang['moveselected'] = 'D&eacute;placer les fichiers s&eacute;lectionn&eacute;s';
$lang['copyselected'] = 'Copier les fichiers s&eacute;lectionn&eacute;s';
$lang['selecttargetdir'] = 'S&eacute;lectionner le dossier de destination pour D&eacute;placer/Copier';
$lang['movedto'] = 'D&eacute;plac&eacute; vers';
$lang['copiedto'] = 'Copier vers';
$lang['couldnotmove'] = 'Ne peut pas &ecirc;tre d&eacute;plac&eacute;';
$lang['couldnotcopy'] = 'Ne peut pas &ecirc;tre copi&eacute;';
$lang['rename'] = 'Renommer';
$lang['newname'] = 'Nouveau nom&nbsp;:';
$lang['renamesuccess'] = 'Le fichier a &eacute;t&eacute; renomm&eacute; avec succ&egrave;s';
$lang['renamefailure'] = 'Le fichier n&#039;a pas &eacute;t&eacute; renomm&eacute;';
$lang['renamecancelled'] = 'Le changement de nom a &eacute;t&eacute; annul&eacute;';
$lang['owner'] = 'Propri&eacute;taire';
$lang['group'] = 'Groupe';
$lang['others'] = 'Autres';
$lang['newpermissions'] = 'Nouvelles permissions&nbsp;:';
$lang['setpermissions'] = 'Donner les permissions';
$lang['permissionstyle'] = 'Style de permissions';
$lang['rwxstyle'] = 'Style rwx';
$lang['755style'] = 'Style 755';
$lang['quickmode'] = 'Chmod rapide (ex : 777)&nbsp;';
$lang['chmod'] = 'Changer les permissions';
$lang['chmodselected'] = 'Changer les permissions sur les fichiers s&eacute;lectionn&eacute;s';
$lang['chmodsuccess'] = 'Le fichier a les nouvelles permissions';
$lang['chmodfailure'] = 'Le fichier n&#039;a pas les nouvelles permissions';
$lang['chmodcancelled'] = 'Le changement des permissions a &eacute;t&eacute; annul&eacute;';
$lang['dirchmodfailmulti'] = 'La modification des permissions sur le dossier a &eacute;chou&eacute;e, une partie du contenu a obtenu de permissions.';
$lang['dirchmodsuccessmulti'] = 'Le changement des permissions sur le dossier et son contenu a &eacute;t&eacute; fait avec succ&egrave;s';
$lang['dirchmodsuccess'] = 'Les permissions sur le dossier sont modifi&eacute;es';
$lang['dirchmodfailure'] = 'La modification des permissions sur le dossier a &eacute;chou&eacute;e';
$lang['dirnotemptyconfirm'] = 'Ce dossier n&#039;est pas vide. Voulez-vous le supprimer ainsi que tout le contenu, y compris les sous dossier ?';
$lang['dirtreedeletecancelled'] = 'Annulation de suppression de dossier';
$lang['imsure'] = 'Je suis s&ucirc;r(e)';
$lang['cancel'] = 'Annuler';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'T&eacute;l&eacute;charger un nouveau fichier&nbsp;:';
$lang['unpackafterupload'] = 'Tentative de d&eacute;compression apr&egrave;s le t&eacute;l&eacute;chargement ?';
$lang['uploadsuccess'] = 'Votre fichier a &eacute;t&eacute; correctement t&eacute;l&eacute;charg&eacute;';
$lang['uploadfail'] = 'Une erreur est survenue lors du t&eacute;l&eacute;chargement du fichier';
$lang['unpacksuccess'] = 'Votre fichier a &eacute;t&eacute; correctement d&eacute;compress&eacute;';
$lang['unpackfail'] = 'Une erreur est survenue lors de la d&eacute;compression du fichier&nbsp;:';
$lang['packfileopenfail'] = 'L&#039;ouverture du fichier archive n&#039;a pas pu s&#039;effectuer par d&eacute;compression (format non-support&eacute;)';
$lang['packfilewritefail'] = 'L&#039;ouverture du fichier %s en &eacute;criture n&#039;a pas pu s&#039;effectuer';
$lang['currentpath'] = 'Chemin actuel&nbsp;:';
$lang['newdirname'] = 'Cr&eacute;er un nouveau dossier&nbsp;:';
$lang['newdirsuccess'] = 'Le dossier a &eacute;t&eacute; cr&eacute;&eacute; avec succ&egrave;s';
$lang['newdirfail'] = 'Une erreur est survenue lors de la cr&eacute;ation du dossier';
$lang['invalidnewdir'] = 'Le nom du dossier ne doit pas contenir des caract&egrave;res comme /, \ et &#039;..&#039; ';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Taille ic&ocirc;ne';
$lang['smallicons'] = 'Petite ic&ocirc;ne';
$lang['largeicons'] = 'Grande ic&ocirc;ne';
$lang['thousanddelimiter'] = 'S&eacute;parateur des miliers';
$lang['none'] = 'Aucun';
$lang['space'] = 'Espace';
$lang['showthumbnails'] = 'Afficher les vignettes';
$lang['showthumbnailshelp'] = 'Si coch&eacute; montre les vignettes des fichiers images si elles existent, et cache les &icirc;cones des fichiers. Non coch&eacute; affiche tous les fichiers.';
$lang['uploadfilesto'] = 'T&eacute;l&eacute;charger les fichiers vers&nbsp;:';
$lang['uploadview'] = 'T&eacute;l&eacute;charger les fichiers';
$lang['uploadboxes'] = 'Nombre de fichiers &agrave; t&eacute;l&eacute;charger ';
$lang['nothinguploaded'] = 'Rien n&#039;a &eacute;t&eacute; t&eacute;l&eacute;charg&eacute;';
$lang['unsupportedarchive'] = 'Format  non support&eacute;';
$lang['uploadmethod'] = 'M&eacute;thode de t&eacute;l&eacute;chargement';
$lang['uploaderstandard'] = 'M&eacute;thode standard html (d&eacute;compression autoris&eacute;e)';
$lang['enableadvanced'] = 'Activer le mode avanc&eacute; ? (si autoris&eacute;)';
$lang['advancedhelp'] = 'Donner acc&egrave;s &agrave; TOUT le syst&egrave;me de fichiers de l&#039;installation CMSMS, pas uniquement &agrave; /uploads/ (si autoris&eacute;)';
$lang['showhiddenfileshelp'] = 'Ne fonctionne qu&#039;en mode avanc&eacute;';
$lang['showhiddenfiles'] = 'Afficher les fichiers cach&eacute;s';
$lang['settingsconfirmsingledelete'] = 'Confirmer la suppression d&#039;un fichier seul ?';
$lang['settingssaved'] = 'Param&egrave;tres sauvegard&eacute;s';
$lang['help'] = '		<h3>Que fait ce module ?</h3>
		<p>Le module Gestionnaire de Fichiers (File Manager) offre des fonctions de gestion de fichiers, et esp&egrave;re remplacer avantageusement le Gestionnaire de Fichiers actuel</p>
		<h3>Comment l&#039;utiliser ?</h3>
		<p>S&eacute;lectionnez-le depuis le menu Contenu de l&#039;administration. Si l&#039;ancien gestionnaire de fichier est pr&eacute;sent, vous devriez trouver celui-ci un peu plus bas dans le menu.</p>';
$lang['utma'] = '156861353.792492233.1240651490.1240651490.1240651490.1';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1240651490.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
?>
